@@ -2,7 +2,7 @@ from django.contrib import admin
 from django import forms
 
 from .genericcollection import GenericCollectionTabularInline
-from .settings import RELATION_MODELS, JAVASCRIPT_URL
+from .settings import RELATION_MODELS, JAVASCRIPT_URL, REGISTER_ADMIN
 from .models import Category
 from .base import CategoryBaseAdminForm, CategoryBaseAdmin
 
@@ -64,7 +64,8 @@ class CategoryAdmin(CategoryBaseAdmin):
     class Media:
         js = (JAVASCRIPT_URL + 'genericcollections.js',)
 
-admin.site.register(Category, CategoryAdmin)
+if REGISTER_ADMIN:
+    admin.site.register(Category, CategoryAdmin)
 
 for model, modeladmin in admin.site._registry.items():
     if model in model_registry.values() and modeladmin.fieldsets:
